@@ -454,7 +454,7 @@ class Spec:
     def isOpaqueElement(self, el: t.ElementT) -> bool:
         if el.tag in self.md.opaqueElements:
             return True
-        if el.get("data-opaque") is not None:
+        if el.get("bs-opaque") is not None:
             return True
         return False
 
